| AppRTCAudioManager | AppRTCAudioManager manages all audio related parts of the AppRTC demo. |
| AppRTCAudioManager.AudioDevice | AudioDevice is the names of possible audio devices that we currently support. |
| AppRTCAudioManager.AudioManagerEvents | Selected audio device change event. |
| AppRTCAudioManager.AudioManagerState | AudioManager state. |
| AppRTCBluetoothManager | AppRTCProximitySensor manages functions related to Bluetoth devices in the AppRTC demo. |
| AppRTCBluetoothManager.State | |
| AppRTCClient | AppRTCClient is the interface representing an AppRTC client. |
| AppRTCClient.SignalingParameters | |
| AppRTCProximitySensor | AppRTCProximitySensor manages functions related to the proximity sensor in the AppRTC demo. |
| AppRTCUtils | AppRTCUtils provides helper functions for managing thread safety. |
| AudioCallEventListener | Created by siltus on 20/09/2017. |
| AudioCallManager | Call Manager. |
| AudioCallManager.AudioCallState | |
| AudioCallStatsListener | Stats report and Mean Opinion Score report for call quality. |
| AudioEarmuffRequest | |
| AudioMuteRequest | Send Mute notification after user has muted himself on the client. |
| AudioRingingRequest |
| Call | Calls can be made towards specified users. |
| Call.CALL_STATE | Enum for Call states. |
| Call.MEMBER_CALL_STATE | Enum for Call Member states.@constant |
| CallEvent | Incoming events from a call. |
| Constants | Networking constants. |
| Conversation | A container that you use to manage communications between Members, the conversation history and context. |
| Conversation.MEDIA_TYPE | |
| ConversationClient | You use a ConversationClient instance to utilise the services provided by Conversation API in your app. |
| ConversationClient.ConversationClientBuilder | API for creating ConversationClient instances. |
| ConversationClient.ConversationClientConfig | POJO which contains current configuration (has to be built by Builder) First step is to acquire a ```ConversationClient``` instance based on a context. |
| ConversationClient.IPSHeader | HTTP headers to be provided to access IPS service's media |
| ConversationClientException | ConversationClientException indicates that an instance of ConversationClient cannot be acquired. |
| ConversationMessagingService |
| Defaults | Defaults. |
| DeliveredReceipt | A delivery receipt confirms delivery of your message, but not that the members involved in the conversation have seen it or read it. |
| DeviceProperties | Utility class for accessing device properties. |
| Event | Event is a foundation for different types of messages |
| EventType |
| Image | Send an image to a Conversation and handle activity receipts. |
| ImageEvent | |
| ImageRepresentation | Each image representation can be defined by type: ImageRepresentation.TYPE. |
| ImageRepresentation.TYPE | |
| InternalNetworkException | Generic network exception. |
| Invitation | Invitation details for any incoming invite. |
| InviteEvent | |
| InviteWithAudioRequest | Invite with audio enabled. |
| InviteWithAudioRequest.AudioInvitation |
| KnockingDeleteRequest | |
| KnockingNewRequest |
| Member | Use this class to retrieve information about a Member and handle state. |
| Member.STATE | |
| Member.TYPING_INDICATOR | |
| MemberMedia | MemberMedia contains an immutable media state for any member. |
| MOSReport | MOS (Mean Opinion Score) report for call quality. |
| NetworkState | Representation connection state of the SDK |
| NexmoAPIError | Nexmo API exception that can be caught and handled, encapsulates following information:
|
| PeerConnectionClient | Peer connection client implementation. |
| PeerConnectionClient.DataChannelParameters | Peer connection parameters. |
| PeerConnectionClient.PeerConnectionEvents | Peer connection events. |
| PeerConnectionClient.PeerConnectionParameters | Peer connection parameters. |
| PendingKnockingRequest | Simple POJO to keep in-memory the outgoing phone call details: call callback and knocking id. |
| PushNotification |
| Receipt<R extends ReceiptRecord> | Receipt details for an event. |
| Receipt.Delivery | |
| Receipt.Seen | |
| ReceiptRecord | Receipt Record holds data for: SeenReceipt and DeliveryReceipt. |
| RequestHandler<T> | Generic event handler, responsible for handling results of events created by user self. |
| ResultListener<T> | Common interface for dispatching events. |
| RtcEvents | |
| RtcNewRequest | Send SDP offer to CAPI, get an rtc_id back |
| RtcNewRequest.RtcNewResponse | |
| RtcTerminateRequest | Send Answer with rtc_id |
| SeenReceipt | Seen receipts for events: of type Text and Image. |
| SessionError | Created by rux on 24/02/17. |
| SIP_CODES | |
| StatsReportHelper | |
| SubscriptionList | Utility list which makes it easier to manage subscriptions and app lifecycle |
| SynchronisingState | Synchronisation information. |
| SynchronisingState.STATE |
| Text | Send a message to a Conversation and handle activity receipts. |
| TextEvent |
| User | A user is a person associated with your Application. |