| com.nexmo.sdk.conversation.client | Provides you with the classes you need to manage contextual communication inside your app. |
| com.nexmo.sdk.conversation.client.audio | |
| com.nexmo.sdk.conversation.client.event | Handle notifications for all objects in com.nexmo.sdk.conversation.client for Events that have been completed. |
| com.nexmo.sdk.conversation.client.event.container | |
| com.nexmo.sdk.conversation.client.event.misc | |
| com.nexmo.sdk.conversation.client.event.network | Listen for networks events in case the socket is disconnected at any stage without prior notice. |
| com.nexmo.sdk.conversation.config | |
| com.nexmo.sdk.conversation.core | |
| com.nexmo.sdk.conversation.core.client.request | |
| com.nexmo.sdk.conversation.core.client.request.audio | |
| com.nexmo.sdk.conversation.core.networking | |
| com.nexmo.sdk.conversation.core.util | |
| com.nexmo.sdk.conversation.device | |
| com.nexmo.sdk.conversation.push |